@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,10 +7,7 @@
 #pragma once
 #include "korganizerprivate_export.h"
 #include <PimCommonActivities/ActivitiesBaseManager>
-namespace KActivities
-{
-class Consumer;
-}
+class TransportActivities;
 class AccountActivities;
 class KORGANIZERPRIVATE_EXPORT ActivitiesManager : public PimCommonActivities::ActivitiesBaseManager
 {
@@ -21,13 +18,10 @@ public:
     explicit ActivitiesManager(QObject *parent = nullptr);
     ~ActivitiesManager() override;
 
-    [[nodiscard]] bool enabled() const override;
-    void setEnabled(bool newEnabled);
-
-    AccountActivities *accountActivities() const;
+    [[nodiscard]] TransportActivities *transportActivities() const;
+    [[nodiscard]] AccountActivities *accountActivities() const;
 
 private:
-    KActivities::Consumer *const mActivitiesConsumer;
     AccountActivities *const mAccountActivities;
-    bool mEnabled = false;
+    TransportActivities *const mTransportActivities;
 };
