@@ -29,37 +29,37 @@ public:
     ~KOAgendaView() override;
 
     /** Returns maximum number of days supported by the koagendaview */
-    Q_REQUIRED_RESULT int maxDatesHint() const override;
+    [[nodiscard]] int maxDatesHint() const override;
 
     /** Returns number of currently shown dates. */
-    Q_REQUIRED_RESULT int currentDateCount() const override;
+    [[nodiscard]] int currentDateCount() const override;
 
     /** returns the currently selected events */
-    Q_REQUIRED_RESULT Akonadi::Item::List selectedIncidences() override;
+    [[nodiscard]] Akonadi::Item::List selectedIncidences() override;
 
     /** returns the currently selected incidence's dates */
-    Q_REQUIRED_RESULT KCalendarCore::DateList selectedIncidenceDates() override;
+    [[nodiscard]] KCalendarCore::DateList selectedIncidenceDates() override;
 
     /** return the default start/end date/time for new events   */
-    Q_REQUIRED_RESULT bool eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) override;
+    [[nodiscard]] bool eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) override;
 
-    Q_REQUIRED_RESULT CalendarSupport::CalPrinter::PrintType printType() const override;
+    [[nodiscard]] CalendarSupport::CalPrinter::PrintType printType() const override;
 
     /** start-datetime of selection */
-    Q_REQUIRED_RESULT QDateTime selectionStart() override;
+    [[nodiscard]] QDateTime selectionStart() override;
 
     /** end-datetime of selection */
-    Q_REQUIRED_RESULT QDateTime selectionEnd() override;
+    [[nodiscard]] QDateTime selectionEnd() override;
 
     /** returns true if selection is for whole day */
-    Q_REQUIRED_RESULT bool selectedIsAllDay();
+    [[nodiscard]] bool selectedIsAllDay();
     /** make selected start/end invalid */
     void deleteSelectedDateTime();
     /** returns if only a single cell is selected, or a range of cells */
-    Q_REQUIRED_RESULT bool selectedIsSingleCell();
+    [[nodiscard]] bool selectedIsSingleCell();
 
     /* reimp from BaseView */
-    void setCalendar(const Akonadi::ETMCalendar::Ptr &cal) override;
+    void setModel(QAbstractItemModel *model) override;
 
     void setTypeAheadReceiver(QObject *o) override;
 
@@ -93,6 +93,9 @@ public Q_SLOTS:
 
     void zoomView(const int delta, const QPoint &pos, const Qt::Orientation orient = Qt::Horizontal);
 
+    void calendarAdded(const Akonadi::CollectionCalendar::Ptr &calendar) override;
+    void calendarRemoved(const Akonadi::CollectionCalendar::Ptr &calendar) override;
+
 Q_SIGNALS:
     void zoomViewHorizontally(const QDate &, int count);
     void timeSpanSelectionChanged();
